/*!
 * \file
 * \brief UsbUart Click example
 *
 * # Description
 * This demo example shows UART communication using USB UART click.
 *
 * The demo application is composed of two sections :
 *
 * ## Application Init
 * Configuring clicks and log objects.
 *
 * ## Application Task
 * Depending on the selected application mode:
 *  - DEMO_APP_TRANSMITER - Prints "MikroE" message to UART
 *  - DEMO_APP_RECEIVER - Reads data from uart and prints to LOG (Default)
 *
 * \author Katarina Perendic
 *
 */
// ------------------------------------------------------------------- INCLUDES

#include "board.h"
#include "log.h"
#include "usbuart.h"

// ------------------------------------------------------------------ VARIABLES

#define DEMO_APP_RECEIVER
//#define DEMO_APP_TRANSMITER

static usbuart_t usbuart;
static log_t logger;

static usbuart_data_t demo_message[ 9 ] = { 'M', 'i', 'k', 'r', 'o', 'E', 13, 10, 0 };

// ------------------------------------------------------ APPLICATION FUNCTIONS

void application_init ( void )
{
    log_cfg_t log_cfg;
    usbuart_cfg_t cfg;

    //  Logger initialization.

    log_cfg.level = LOG_LEVEL_DEBUG;
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, "---- Application Init ----" );

    //  Click initialization.

    usbuart_cfg_setup( &cfg );
    USBUART_MAP_MIKROBUS( cfg, MIKROBUS_1 );
    usbuart_init( &usbuart, &cfg );

    usbuart_default_cfg ( &usbuart );
}

void application_task ( void )
{
    uint8_t tmp;

    //  Task implementation.

#ifdef DEMO_APP_RECEIVER

       // RECEIVER - UART polling

       tmp =  usbuart_generic_single_read( &usbuart );
       log_write( &logger, &tmp, LOG_FORMAT_BYTE );
#endif
#ifdef DEMO_APP_TRANSMITER

       // TRANSMITER - TX each 2 sec

       usbuart_generic_multi_write( &usbuart, demo_message, 9 );
       Delay_ms( 2000 );
#endif

}

void main ( void )
{
    application_init( );

    for ( ; ; )
    {
        application_task( );
    }
}


// ------------------------------------------------------------------------ END
