
 

---
# USB UART click

USB UART click offers a USB to asynchronous serial data (UART) interface, allowing the microcontroller based designs to communicate with the personal computer, in a very simple way.

<p align="center">
  <img src="https://download.mikroe.com/images/click_for_ide/grupe/usb-uart-group.png">
</p>

> - [Product page - USB UART click](<https://www.mikroe.com/usb-uart-click>)
> - [Product page - USB UART 2 click](<https://www.mikroe.com/usb-uart-2-click>)
> - [Product page - USB UART 4 click](<https://www.mikroe.com/usb-uart-4-click>)

---

#### Click library 

- **Author**        : Katarina Perendic
- **Date**          : nov 2019.
- **Type**          : UART type


# Software Support

We provide a library for the UsbUart Click 
as well as a demo application (example), developed using MikroElektronika 
[compilers](http://shop.mikroe.com/compilers). 
The demo can run on all the main MikroElektronika [development boards](http://shop.mikroe.com/development-boards).

Package can be downloaded/installed directly form compilers IDE(recommended way), or downloaded from our LibStock, or found on mikroE github account. 

## Library Description

> This library contains API for UsbUart Click driver.

#### Standard key functions :

- Config Object Initialization function.
> void usbuart_cfg_setup ( usbuart_cfg_t *cfg ); 
 
- Initialization function.
> USBUART_RETVAL usbuart_init ( usbuart_t *ctx, usbuart_cfg_t *cfg );

- Click Default Configuration function.
> void usbuart_default_cfg ( usbuart_t *ctx );


#### Example key functions :

- Set device mode
> void usbuart_set_mode ( usbuart_t *ctx, uint8_t mode );
 
- Generic single write function
> void usbuart_generic_single_write ( usbuart_t *ctx, usbuart_data_t tx_data );

- Generic single read function
> usbuart_data_t usbuart_generic_single_read ( usbuart_t *ctx );

## Examples Description

> This demo example shows UART communication using USB UART click.

**The demo application is composed of two sections :**

### Application Init 

> Configuring clicks and log objects. 

```c
void application_init ( void )
{
    log_cfg_t log_cfg;
    usbuart_cfg_t cfg;

    //  Logger initialization.

    log_cfg.level = LOG_LEVEL_DEBUG;
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    /log_info( &logger, "---- Application Init ----" );

    //  Click initialization.

    usbuart_cfg_setup( &cfg );
    USBUART_MAP_MIKROBUS( cfg, MIKROBUS_1 );
    usbuart_init( &usbuart, &cfg );

    usbuart_default_cfg ( &usbuart );
}
```

### Application Task

> Depending on the selected application mode:
>  - DEMO_APP_TRANSMITER - Prints "MikroE" message to UART 
>  - DEMO_APP_RECEIVER - Reads data from uart and prints to LOG (Default)

```c
void application_task ( void )
{
    uint8_t tmp;
    
    //  Task implementation.
    
#ifdef DEMO_APP_RECEIVER

       // RECEIVER - UART polling

       tmp =  usbuart_generic_single_read( &usbuart );
       log_write( &logger, &tmp, LOG_FORMAT_BYTE );
#endif
#ifdef DEMO_APP_TRANSMITER

       // TRANSMITER - TX each 2 sec
       
       usbuart_generic_multi_write( &usbuart, demo_message, 9 );
       Delay_ms( 2000 );
#endif
}
```

The full application code, and ready to use projects can be  installed directly form compilers IDE(recommneded) or found on LibStock page or mikroE GitHub accaunt.

**Other mikroE Libraries used in the example:** 

- MikroSDK.Board
- MikroSDK.Log
- Click.UsbUart

**Additional notes and informations**

Depending on the development board you are using, you may need 
[USB UART click](http://shop.mikroe.com/usb-uart-click), 
[USB UART 2 Click](http://shop.mikroe.com/usb-uart-2-click) or 
[RS232 Click](http://shop.mikroe.com/rs232-click) to connect to your PC, for 
development systems with no UART to USB interface available on the board. The 
terminal available in all Mikroelektronika 
[compilers](http://shop.mikroe.com/compilers), or any other terminal application 
of your choice, can be used to read the message.



---
